package rabbit.client;

import rabbit.http.HttpHeader;
import rabbit.io.BufferHandle;
import rabbit.io.WebConnection;

public interface ClientListener {
    /** Handle a redirected request
     * @param request the request that was redirected
     * @param location the location the redirect gives
     */
    void redirected (HttpHeader request, String location, ClientBase base);

    /** Handle a response for a request.
     * @param request the request made
     * @param response the response header 
     * @param bufferHandle the BufferHandle used, may contain resource data
     * @param keepalive a flag indicating if keepalive seems possible for 
     *                  this connection.
     * @param isChunked a flag to tell if the resource is chunked or not
     * @param dataSize the size of the resource, may be -1 if unknown
     */
    void handleResponse (HttpHeader request, HttpHeader response, 
			 WebConnection wc, BufferHandle bufferHandle, 
			 boolean keepalive, boolean isChunked, long dataSize);
    
    /** Check if this client request wants to automatically follow redirects */
    boolean followRedirects ();

    /** Handle a timeout of a given request. */
    void handleTimeout (HttpHeader request);

    /** Handle a failure of a given request. */
    void handleFailure (HttpHeader request, Exception e);

}
