package rabbit.client;

import java.io.IOException;
import java.util.concurrent.atomic.AtomicInteger;
import rabbit.http.HttpHeader;
import rabbit.io.BufferHandle;
import rabbit.io.WebConnection;
import rabbit.util.Logger;

/** A class that performs a HEAD request to the given urls.
 *  This is mostly an example of how to use the rabbit client classes.
 *
 * @author <a href="mailto:robo@khelekore.org">Robert Olofsson</a>
 */
public class Head {
    private AtomicInteger outstandingRequests = new AtomicInteger ();
    private ClientBase clientBase;
    
    public static void main (String[] args) {
	try {
	    Head h = new Head ();
	    h.head (args);
	} catch (IOException e) {
	    e.printStackTrace ();
	}
    }

    public Head () throws IOException {
	clientBase = new ClientBase ();
    }

    public void head (String[] urls) throws IOException {
	for (String url : urls) 
	    head (url);
    }

    public void head (String url) throws IOException {
	outstandingRequests.incrementAndGet ();
	clientBase.sendRequest (clientBase.getRequest ("HEAD", url),
				new HeadListener (clientBase.getLogger ()));
    }

    private void decrementOutstanding () {
	int outstanding = outstandingRequests.decrementAndGet ();
	if (outstanding == 0)
	    clientBase.shutdown ();
    }
    
    private class HeadListener extends ClientListenerAdapter {   
	public HeadListener (Logger logger) {
	    super (logger);
	}

	@Override public void redirectedTo (String url) throws IOException {
	    head (url);
	}

	@Override public void handleResponse (HttpHeader request, 
					      HttpHeader response, 
					      WebConnection wc,
					      BufferHandle bufferHandle, 
					      boolean keepalive, boolean isChunked,
					      long dataSize) {
	    System.out.print (request.getRequestURI () + "\n" + response);
	    clientBase.getConnectionHandler ().releaseConnection (wc);
	    requestDone ();
	}

	@Override public void requestDone () {
	    decrementOutstanding ();
	}
    }
}
